@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,6 +33,7 @@
 #include "make_settings_entries.h"
 #include "make_settings_combos.h"
 #include "make_settings_labels.h"
+#include "make_settings_hseparators.h"
 #include "save_backup_settings.h"
 #include "commands.h"
 #include "cron_functions.h"
@@ -46,8 +47,8 @@
 extern gchar *global_settings_dir;
 extern gchar *global_backup_name;
 
-gulong backup_combo_changed_signal;
-
+/* Used to see if the backup combo changed */
+extern gulong backup_combo_changed_signal;
 
 
 /* Change cell text in a treeview */
@@ -221,10 +222,10 @@ void create_new_backup(struct w *widgets)
 }
 
 
-/* Deletes the selected backup and schedule if any then repopulates the gui */
+/* Deletes the selected backup, schedule and logs then repopulates the gui */
 void delete_backup(struct w *widgets)
 {
-    gchar *info, *conf_file, *script_file, *script_log_file;
+    gchar *info, *conf_file, *script_file, *log_file;
 
     conf_file = g_strdup_printf("%s/%s", global_settings_dir, global_backup_name);
 
@@ -256,18 +257,33 @@ void delete_backup(struct w *widgets)
     if( script_file!=NULL )
       g_free(script_file);
 
-    /* Delete the script log file if any */
-    script_log_file = mk_script_log_path(global_backup_name);
-    if( script_log_file!=NULL && strstr(script_log_file, "gadmin-rsync") )
-      unlink(script_log_file);
+    /* Delete the log file if any */
+    log_file = mk_log_path(global_backup_name);
+    if( log_file!=NULL && strstr(log_file, "gadmin-rsync") )
+      unlink(log_file);
 
-    if( script_log_file!=NULL )
-      g_free(script_log_file);
+    if( log_file!=NULL )
+      g_free(log_file);
+
+    /* Delete the extended log file if any */
+    log_file = mk_extended_log_path(global_backup_name);
+    if( log_file!=NULL && strstr(log_file, "gadmin-rsync") )
+      unlink(log_file);
+
+    if( log_file!=NULL )
+      g_free(log_file);
+
+    /* Clear the "backup name" combo. Block its signal first. */
+    g_signal_handler_block(GTK_WIDGET(widgets->rsync_set_combo[0]), backup_combo_changed_signal);
 
-    /* Clear the "backup name" combo */
     GtkTreeModel *model = gtk_combo_box_get_model(GTK_COMBO_BOX(widgets->rsync_set_combo[0]));
     gtk_list_store_clear(GTK_LIST_STORE(model));
 
+    /* Unblock its signal */
+    g_signal_handler_unblock(GTK_WIDGET(widgets->rsync_set_combo[0]), backup_combo_changed_signal);
+
+    /* Delete the logs */
+
     populate_rsync_tab(widgets);
 }
 
@@ -296,7 +312,7 @@ void create_new_backup_window(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(vbox), frame, TRUE, TRUE, 1);
     gtk_container_add(GTK_CONTAINER(frame), table);
 
-    widgets->new_backup_entry = make_entry_with_label(GTK_TABLE(table), _(" The name of the new backup: "), 0,1,0,1, 300);
+    widgets->new_backup_entry = make_entry_with_label(GTK_TABLE(table), _(" Name of the new backup: "), 0,1,0,1, 300);
 
     /* Apply and cancel buttons */
     GtkWidget *hbuttonbox = gtk_hbutton_box_new();
@@ -338,7 +354,7 @@ void create_rsync_tab(struct w *widgets)
     user_settings_treeview_hbox = gtk_hbox_new(TRUE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->notebook_vbox1), user_settings_treeview_hbox, EXPAND_USER_SETTINGS_SECTION, TRUE, 0);
 
-    widgets->user_settings_scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    widgets->user_settings_scrolled_window = gtk_scrolled_window_new(NULL, NULL);
     gtk_box_pack_start(GTK_BOX(user_settings_treeview_hbox), widgets->user_settings_scrolled_window, TRUE, TRUE, 0);
     gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(widgets->user_settings_scrolled_window), 
 						    GTK_POLICY_AUTOMATIC, 
@@ -560,19 +576,18 @@ void create_rsync_tab(struct w *widgets)
     GtkWidget *label221 = gtk_label_new_with_mnemonic(_("Delete selected backup"));
     gtk_box_pack_start(GTK_BOX(hbox40), label221, FALSE, FALSE, 0);
     gtk_label_set_justify(GTK_LABEL(label221), GTK_JUSTIFY_LEFT);
+
     /* Delete selected backup signal hookup */
     g_signal_connect_swapped(del_backup_button, "clicked",
-                    	     G_CALLBACK(delete_backup), widgets);
+            	        G_CALLBACK(delete_backup), widgets);
 
     /* Selected backup combo */
     utf8 = g_locale_to_utf8(_(" Selected backup: "), -1, NULL, NULL, NULL);
     widgets->rsync_set_combo[0] = make_label_combo_button(GTK_TABLE(widgets->usr_set_table), del_backup_button, utf8, 0,1,a,b, 350);
 
-    /* Callback for combo changed. Save the signal id so the signal emission can be blocked. */
+    /* Callback for combo changed. */
     backup_combo_changed_signal = g_signal_connect_swapped(widgets->rsync_set_combo[0], "changed",
-                    	        		    G_CALLBACK(backup_name_combo_changed), widgets);
-
-
+    		    				    G_CALLBACK(backup_name_combo_changed), widgets);
 
     a++; b++;
 
@@ -581,8 +596,6 @@ void create_rsync_tab(struct w *widgets)
     make_3columns_label(GTK_TABLE(widgets->usr_set_table), "", 0, 1, a, b);
     a++; b++;				
 
-
-// FIXME: Doesnt spread...
     GtkWidget *hbuttonbox2;
     hbuttonbox2 = gtk_hbutton_box_new();
     gtk_table_attach(GTK_TABLE(widgets->usr_set_table), hbuttonbox2, 0, 3, a, b, FALSE, FALSE, 2, 2);
@@ -607,9 +620,6 @@ void create_rsync_tab(struct w *widgets)
                     	     G_CALLBACK(create_new_backup_window), widgets);
 
 
-// Fixme: Add a spacer label to hbuttonbox2 or something here....
-
-
     /* Save backup button */
     GtkWidget *save_backup_button = gtk_button_new();
     gtk_tooltips_set_tip(tooltips, save_backup_button, _("Save this backup."), NULL);
@@ -646,64 +656,107 @@ void create_rsync_tab(struct w *widgets)
     gtk_box_pack_start(GTK_BOX(hbuttonbox2), log_backup_button, FALSE, FALSE, 0);
     /* Show log button signal hookup */
     g_signal_connect_swapped(log_backup_button, "clicked",
-                    	     G_CALLBACK(show_log), widgets);
+                    	     G_CALLBACK(show_log_window), widgets);
     a++; b++;
 
-
-
     /* Spacer label */
     make_3columns_label(GTK_TABLE(widgets->usr_set_table), "", 0, 1, a, b);
     a++; b++;				
 
-
-    /* Schedule settings... */
+    /* CRON Time schedule settings */
     widgets->schedule_check_button[0] = make_3columns_label_spin(GTK_TABLE(widgets->usr_set_table),
-                     _("Schedule this backup to run at specific days via cron: "), 0, 1, a, b);
+    _("Schedule this backup to run at specific times: "), 0, 1, a, b);
+    a++; b++;				
 
-    gtk_tooltips_set_tip(tooltips, widgets->schedule_check_button[0],
-     _("The backup will run every day of the week if no days are selected."), NULL);
+    /* Hseparator */
+    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
+    a++; b++;				
+
+    /* Schedule (Month day = 1-31) */
+    widgets->schedule_spin_button[0] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    _("Month day"), 0, 1, a, b, 20, 1, 31);
+
+    gtk_tooltips_set_tip(tooltips, widgets->schedule_spin_button[0],
+    _("The backup will run on the specified day of the month.\nUncheck any weekdays to have a monthly backup."), NULL);
+    a++; b++;
+
+    /* Any month day (*) */
+    widgets->schedule_check_button[1] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    _("Not monthly: "), 0, 1, a, b);
+
+    gtk_tooltips_set_tip(tooltips, widgets->schedule_check_button[1],
+    _("If selected, the backup will run on the specified days and times instead of once a month."), NULL);
+    a++; b++;
+
+    /* Hseparator */
+    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
     a++; b++;				
 
     /* Schedule days */
-    widgets->schedule_check_button[1] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[2] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Monday: "), 0, 1, a, b);
     a++; b++;
-    widgets->schedule_check_button[2] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[3] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Tuesday: "), 0, 1, a, b);
     a++; b++;
-    widgets->schedule_check_button[3] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[4] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Wednesday: "), 0, 1, a, b);
     a++; b++;
-    widgets->schedule_check_button[4] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[5] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Thursday: "), 0, 1, a, b);
     a++; b++;
-    widgets->schedule_check_button[5] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[6] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Friday: "), 0, 1, a, b);
     a++; b++;
-    widgets->schedule_check_button[6] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[7] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Saturday: "), 0, 1, a, b);
     a++; b++;
-    widgets->schedule_check_button[7] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    widgets->schedule_check_button[8] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
                                                                             _("Sunday: "), 0, 1, a, b);
     a++; b++;
 
-    /* Should schedule time be included. (This is a checkbutton, defined in make_settings_labels.c) */
-    widgets->schedule_check_button[8] = make_3columns_label_spin(GTK_TABLE(widgets->usr_set_table),
-                     _("Schedule this backup to run at a specific time via cron: "), 0, 1, a, b);
+    /* Hseparator */
+    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
+    a++; b++;				
 
-    gtk_tooltips_set_tip(tooltips, widgets->schedule_check_button[8],
-     _("The backup will run every minute if both hour and minute are set to zero. The backup will run every minute every scheduled day if time is not scheduled"), NULL);
-    a++; b++;
-
-    /* Schedule hour   (0-23) (0 means any '*') */
-    widgets->schedule_spin_button[0] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
-    									     _("Hour"), 0, 1, a, b, 20, 0, 23);
-    /* Schedule minute (0-59) (0 means any '*') */
-    a++; b++;
+    /* Schedule hour   (0-23) */
     widgets->schedule_spin_button[1] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+    									     _("Hour"), 0, 1, a, b, 20, 0, 23);
+    a++; b++;
+
+    /* Every hour   (*) */
+    widgets->schedule_check_button[9] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+                                                                            _("Every hour: "), 0, 1, a, b);
+    a++; b++;
+
+    /* Hseparator */
+    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
+    a++; b++;				
+
+    /* Schedule minute (0-59) */
+    widgets->schedule_spin_button[2] = make_shortleft_spinbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
 									   _("Minute"), 0, 1, a, b, 20, 0, 59);
     a++; b++;
 
+    /* Every minute (*) */
+    widgets->schedule_check_button[10] = make_checkbutton_with_label(GTK_TABLE(widgets->usr_set_table), 
+                                                                            _("Every minute: "), 0, 1, a, b);
+    a++; b++;
+
+    /* Hseparator */
+//    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
+//    a++; b++;				
+
+    // Backup at shutdown [X]
+
+    /* Hseparator */
+//    make_3columns_hseparator(GTK_TABLE(widgets->usr_set_table), 0, 1, a, b);
+//    a++; b++;				
+    
+    // Pre for dumping databases, post for cleaning up etc...
+    // Pre command  ( Commands to run before the source is backed up. )
+    // Post command ( Commands to run after the backup. )
+
     if( utf8!=NULL )
       g_free(utf8);
 
