@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,8 +22,11 @@
 #ifndef CRON_FUNCTIONS_H
 #define CRON_FUNCTIONS_H
 
-gchar *mk_script_log_path(gchar *backup_name);
+gchar *sanitize_backup_name(gchar *backup_name);
+gchar *mk_log_path(gchar *backup_name);
+gchar *mk_extended_log_path(gchar *backup_name);
 gchar *mk_script_path(gchar *backup_name);
+
 void schedule_cron(gchar *cron_line, gchar *backup_name);
 void add_cron(gchar *cron_line, gchar *script_path);
 void del_cron(gchar *script_path);
