@@ -1,4 +1,5 @@
-/* Copyright (C) 2007 Magnus Loef <magnus-swe@telia.com> 
+/* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
+ * Copyright (C) 2007-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,8 +78,9 @@ int populate_backup_combo(struct w *widgets)
 
     for(x=0; x<i; x++)
     {
-	/* Skip the dots */
-	if( strstr(namelist[x]->d_name, ".") )
+	/* Skip the directory up/down dots */
+	if( strcmp(namelist[x]->d_name, ".")  == 0
+	||  strcmp(namelist[x]->d_name, "..") == 0 )
 	{
 	    free(namelist[x]);
 	    continue;
@@ -102,7 +104,7 @@ int populate_backup_combo(struct w *widgets)
 	}
 
 	/* If theres a selected "backup name", set it as selected if found */
-	if( global_backup_name!=NULL && ! strcmp(global_backup_name, namelist[x]->d_name) )
+	if( global_backup_name!=NULL && strcmp(global_backup_name, namelist[x]->d_name) == 0 )
 	{
 	    gtk_combo_box_set_active(GTK_COMBO_BOX(widgets->rsync_set_combo[0]), x-2);
 
@@ -124,24 +126,26 @@ int populate_backup_combo(struct w *widgets)
 }
 
 
-
+/* Inserts rsync tab settings */
 void populate_rsync_tab(struct w *widgets)
 {
-    /* Inserts rsync settings */
     FILE *fp;
     long opt_pos=0, conf_size=0;
     char *line, *opt, *new_buffer, *timebuf;
     gchar *conf_file = NULL, *utf8 = NULL;
     GtkTreeIter iter;
-    int count=0, prev_newline=0, one_time=0, i=0, x=0;
+    int prev_newline=0, one_time=0, i=0, x=0;
 
     /* Clear the treeview */
     gtk_list_store_clear(GTK_LIST_STORE(widgets->backup_store));
 
-//g_signal_handlers_block_by_func(GTK_WIDGET(widgets->rsync_set_combo[0]),
-//                                populate_backup_combo, widgets);
-
-
+    /* Deselect all toggle buttons */
+    for(i=0; i<10; i++)
+    {
+	gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i]), FALSE);
+    }
+    /* Set it to any month by default */
+    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[1]), TRUE);
 
     /* Populate the backup combo */
     if( populate_backup_combo(widgets) )
@@ -157,7 +161,6 @@ void populate_rsync_tab(struct w *widgets)
         return;
     }
 
-
     /* Populate the backup treeview with this conf file */
     if((fp=fopen(conf_file, "r"))==NULL)
     {
@@ -182,7 +185,7 @@ void populate_rsync_tab(struct w *widgets)
 	if( strlen(line) > 16384 )
 	  continue;
 
-	if( ! strstr(line,"schedule_days") && ! strstr(line, "schedule_time") )
+	if( ! strstr(line,"schedule_") ) 
 	{
 	    /* Append a row once if the data length is valid */
 	    if( ! one_time && strlen(line) > 3 )
@@ -303,37 +306,56 @@ void populate_rsync_tab(struct w *widgets)
 	}
 
 
+	/* Is scheduling used... */
+	if( strstr(line, "schedule_") )
+	{
+	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0]), TRUE);
+	}
 
-	/* Schedule_days */
+	/* Schedule month day */
+	if( strstr(line, "schedule_month_day") )
+	{
+	    timebuf[0]='\0';
+	    x = 1; /* Default value */
+	    
+	    /* Get and insert the month day */
+	    for(i=0; i<5 && opt[i]!='\0'; i++)
+	    {
+		timebuf[i] = opt[i];
+	    }
+	    if( timebuf[strlen(timebuf)-1]=='\n' )
+	      timebuf[strlen(timebuf)-1]='\0';
+
+	    x = atoi(timebuf);
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[0]), x);
+
+	    /* Uncheck shedule every month day */
+	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[1]), FALSE);
+	}
+	/* Schedule every month day is enabled */
+	if( strstr(line, "schedule_every_month_day") )
+	{
+	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[1]), TRUE);
+	}
+
+	/* Schedule days */
 	if( strstr(line, "schedule_days") )
 	{
-	    /* Schedule days is enabled */
-	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0]), TRUE);
-
 	    for(i=0; opt[i]!='\0'; i++)
 	    {
-		if( i < 8 )
+		if( i < 9 )
 		{
-		    /* Checkbuttons are 1-7 */
+		    /* Checkbuttons are 2-8 */
 		    if( opt[i]=='1' )
-		      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i+1]), TRUE);
+		      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i+2]), TRUE);
 		    else
-		      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i+1]), FALSE);
+		      gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i+2]), FALSE);
 		}
 	    }	    
 	}
-	/* Schedule_time */
+	/* Schedule time (hour, minute) */
 	if( strstr(line, "schedule_time") )
 	{
-	    /* Schedule time enabled */
-	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[8]), TRUE);
-
-	    if( strlen(line) > MAX_TIME_LINE )
-	    {
-		printf("Populate_rsync_tab.c: schedule_time line too long, skipping.\n");
-		continue;
-	    }
-
 	    /* Contains hour or minute (12:30) */
 	    timebuf[0]='\0';
 	    x = 1; /* Default value */
@@ -347,7 +369,7 @@ void populate_rsync_tab(struct w *widgets)
 	      timebuf[strlen(timebuf)-1]='\0';
 
 	    x = atoi(timebuf);
-	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[0]), x);
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[1]), x);
 
 	    /* Skip colon */
 	    i++;
@@ -366,7 +388,18 @@ void populate_rsync_tab(struct w *widgets)
 	      timebuf[strlen(timebuf)-1]='\0';
 
 	    x = atoi(timebuf);
-	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[1]), x);
+	    gtk_spin_button_set_value(GTK_SPIN_BUTTON(widgets->schedule_spin_button[2]), x);
+	}
+
+	/* Schedule every hour is enabled */
+	if( strstr(line, "schedule_every_hour") )
+	{
+	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[9]), TRUE);
+	}
+	/* Schedule every minute is enabled */
+	if( strstr(line, "schedule_every_minute") )
+	{
+	    gtk_toggle_button_set_state(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[10]), TRUE);
 	}
     }
     fclose(fp);
