@@ -1,5 +1,5 @@
 /* GAdmin-Rsync - An easy to use GTK+ frontend for the rsync backup client and server.
- * Copyright (C) 2007 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2007-2009 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -74,7 +74,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
                       GtkTreeIter *iter, struct w *widgets)
 {
     FILE *fp;
-    gchar *settings_file, *setting=NULL, *script_file, *script, *script_log_file, *info;
+    gchar *settings_file, *setting=NULL, *script_file, *script, *log_file, *info;
     gchar *src_server=NULL, *src_path=NULL, *dst_server=NULL, *dst_path=NULL;
     gchar *include_files=NULL, *exclude_files=NULL;
     gint include_in_backup_script = 0;
@@ -260,8 +260,8 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 
 
 
-    /* Create the name of the log file */
-    script_log_file = mk_script_log_path(global_backup_name);
+    /* Create the log file path */
+    log_file = mk_log_path(global_backup_name);
 
 
 
@@ -277,7 +277,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 	   USB-disks with sleep-modes can loose contact and dismount or not mount etc */
 	setting = g_strconcat("if [ ! -e '", dst_path, "' ]; then\n",
 	"	MISSING_PATH=1\n",
-	"	echo -n Missing_destination_path:_ >> ", script_log_file,"\n",
+	"	echo -n Missing_destination_path:_ >> ", log_file,"\n",
 	"else\n",
 	"	MISSING_PATH=0\n",
 	NULL);
@@ -288,7 +288,12 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 	  fputs("rsync --archive --human-readable --verbose --stats --delete --force", fp);
 	else
 	  fputs("rsync --archive --human-readable --verbose --stats", fp);
-	
+
+	/* Add a detailed log for each backup */
+	setting = g_strdup_printf(" --log-file=%s.details", log_file);
+	fputs(setting, fp);
+	g_free(setting);
+
 	if( has_value(include_files) )
 	{
 	    fputs(" --include=\"", fp);
@@ -328,7 +333,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 
 	setting = g_strconcat("if [ ! -e '", dst_path, "' ]; then\n",
 	"	MISSING_PATH=1\n",
-	"	echo -n Missing_destination_path:_ >> ", script_log_file,"\n",
+	"	echo -n Missing_destination_path:_ >> ", log_file,"\n",
 	"else\n",
 	"	MISSING_PATH=0\n",
 	NULL);
@@ -340,6 +345,11 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 	else
 	  fputs("rsync --archive --progress --human-readable --verbose --stats", fp);
 
+	/* Add a detailed log for each backup */
+	setting = g_strdup_printf(" --log-file=%s.details", log_file);
+	fputs(setting, fp);
+	g_free(setting);
+
 	
 	if( has_value(include_files) )
 	{
@@ -392,7 +402,7 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 
 	setting = g_strconcat("if [ ! -e '", src_path, "' ]; then\n",
 	"	MISSING_PATH=1\n",
-	"	echo -n Missing_source_path:_ >> ", script_log_file,"\n",
+	"	echo -n Missing_source_path:_ >> ", log_file,"\n",
 	"else\n",
 	"	MISSING_PATH=0\n",
 	NULL);
@@ -404,7 +414,11 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 	else
 	  fputs("rsync --archive --progress --human-readable --verbose --stats", fp);
 
-	
+	/* Add a detailed log for each backup */
+	setting = g_strdup_printf(" --log-file=%s.details", log_file);
+	fputs(setting, fp);
+	g_free(setting);
+
 	if( has_value(include_files) )
 	{
 	    fputs(" --include=\"", fp);
@@ -450,10 +464,10 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
        rsync line that appends to the current backups logfile */
     script = g_strconcat("\nif [ $? -eq 0 ] && [ $MISSING_PATH -eq 0 ]; then\n",
     "   STOP_TIME=`date +%Y-%m-%d_%H:%M:%S`;\n",
-    "   echo \"$START_TIME $STOP_TIME Backup successful: Source: [", source, "] Destination: [", destination, "]\" >> ", script_log_file,
+    "   echo \"$START_TIME $STOP_TIME Backup successful: Source: [", source, "] Destination: [", destination, "]\" >> ", log_file,
     "\nelse\n"
     "   STOP_TIME=`date +%Y-%m-%d_%H:%M:%S`;\n",
-    "   echo \"$START_TIME $STOP_TIME Backup failure:    Source: [", source, "] Destination: [", destination, "]\" >> ", script_log_file,
+    "   echo \"$START_TIME $STOP_TIME Backup failure:    Source: [", source, "] Destination: [", destination, "]\" >> ", log_file,
     "\nfi\n\n",
     NULL);
 
@@ -467,8 +481,8 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
     if( script!=NULL )
 	g_free(script);
 
-    if( script_log_file!=NULL )
-	g_free(script_log_file);
+    if( log_file!=NULL )
+	g_free(log_file);
 
     if( source!=NULL )
 	g_free(source);
@@ -485,15 +499,15 @@ gboolean save_foreach(GtkTreeModel *model, GtkTreePath *path,
 }
 
 
+/* Saves the backup settings, backup script and
+   schedules the backup via cron/crontab if specified. */
 void save_backup_settings(struct w *widgets)
 {
-    /* Saves the backup settings, backup script and
-       schedules the backup via cron/crontab if specified. */
     FILE *fp;
     int i = 0;
     gchar *cmd, *info, *settings_file, *script_path, *script, *cron_line;
     char *script_days = NULL;
-    G_CONST_RETURN gchar *script_hour = NULL, *script_minute = NULL;
+    G_CONST_RETURN gchar *script_month_day = NULL, *script_hour = NULL, *script_minute = NULL;
     
     /* Only show one error popup per error type */
     error_src_dst_info       = 1;
@@ -510,8 +524,6 @@ void save_backup_settings(struct w *widgets)
 	return;
     }
 
-
-    
     /* Remove cron lines matching this backup from crontab */
     script_path = mk_script_path(global_backup_name);
     if( script_path == NULL || strlen(script_path) < 3 )
@@ -567,29 +579,25 @@ void save_backup_settings(struct w *widgets)
 	info = g_strdup_printf(_("Error: Can not write backup settings here:\n%s\n"), settings_file);
         show_info(info);
         g_free(info);
-
         g_free(settings_file);
         return;
     }
     fclose(fp);
 
 
-
     /* Iterate the treeview and write the settings and script files */
     gtk_tree_model_foreach(GTK_TREE_MODEL(widgets->backup_store), (GtkTreeModelForeachFunc) save_foreach, widgets);
 
 
-
-    /* Return if schedule time or days via cron isnt enabled */
-    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0]))
-    &&  ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[8])) )
+    /* Return if scheduling is disabled */
+    if( ! gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0])) )
     {
 	/* The cron line has already been removed */
 	g_free(settings_file);
 	return;
     }
 
-    /* Append schedule_days and schedule_time values last in the settings file */
+    /* Append shedule_month, schedule_days and schedule_time values last in the settings file */
     if((fp=fopen(settings_file, "a"))==NULL)
     {
 	info = g_strdup_printf(_("Error: Can not write backup schedule here:\n%s\n"), settings_file);
@@ -600,38 +608,48 @@ void save_backup_settings(struct w *widgets)
         return;
     }
 
-    script_days = allocate(1024);
-
-    /* Schedule days */
-    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[0])) )
+    script_month_day = gtk_entry_get_text(GTK_ENTRY(widgets->schedule_spin_button[0]));
+    /* Run every month is selected */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[1])) )
     {
-	fputs("schedule_days ", fp);
-	for(i=1; i<8; i++)
-	{
-	    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i])) )
-	    {    
-	        fputs("1", fp);
-	        if( i == 1 )
-		    strcat(script_days, "1,");
-	        if( i == 2 )
-		    strcat(script_days, "2,");
-	        if( i == 3 )
-		    strcat(script_days, "3,");
-	        if( i == 4 )
-		    strcat(script_days, "4,");
-	        if( i == 5 )
-		    strcat(script_days, "5,");
-	        if( i == 6 )
-		    strcat(script_days, "6,");
-	        if( i == 7 )
-		    strcat(script_days, "7");
-	    }
-	    else
-	      fputs("0", fp);
-	}
+        fputs("schedule_every_month_day\n", fp);
+        script_month_day = g_strdup_printf("%s", "*");
+    }
+    else
+    {
+	fputs("schedule_month_day ", fp);
+        fputs(script_month_day, fp);
 	fputs("\n", fp);
     }
 
+    fputs("schedule_days ", fp);
+    script_days = allocate(1024);
+    for(i=2; i<9; i++)
+    {
+	if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[i])) )
+	{    
+	    fputs("1", fp);
+
+	    if( i == 2 )
+	      strcat(script_days, "1,");
+	    if( i == 3 )
+	      strcat(script_days, "2,");
+	    if( i == 4 )
+	      strcat(script_days, "3,");
+	    if( i == 5 )
+	      strcat(script_days, "4,");
+	    if( i == 6 )
+	      strcat(script_days, "5,");
+	    if( i == 7 )
+	      strcat(script_days, "6,");
+	    if( i == 8 )
+	      strcat(script_days, "7");
+	}
+	else
+	  fputs("0", fp);
+    }
+    fputs("\n", fp);
+
     /* If there are no script days, add a single '*' for any day */
     if( script_days == NULL || strlen(script_days) < 1 )
       snprintf(script_days, 2, "%s", "*");
@@ -640,32 +658,36 @@ void save_backup_settings(struct w *widgets)
     if( script_days[strlen(script_days)-1]==',' )
       script_days[strlen(script_days)-1]='\0';
 
-    /* Append schedule hour and minute in the settings file */
-    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[8])) )
-    {
-	script_hour   = gtk_entry_get_text(GTK_ENTRY(widgets->schedule_spin_button[0]));
-	script_minute = gtk_entry_get_text(GTK_ENTRY(widgets->schedule_spin_button[1]));
 
-	fputs("schedule_time ", fp);
-	fputs(script_hour, fp);
-	fputs(":", fp);
-	fputs(script_minute, fp);
-	fputs("\n", fp);
+    /* Append schedule for hour and minute in the settings file */
+    script_hour   = gtk_entry_get_text(GTK_ENTRY(widgets->schedule_spin_button[1]));
+    script_minute = gtk_entry_get_text(GTK_ENTRY(widgets->schedule_spin_button[2]));
+
+    fputs("schedule_time ", fp);
+    fputs(script_hour, fp);
+    fputs(":", fp);
+    fputs(script_minute, fp);
+    fputs("\n", fp);
+
+    /* Run every hour */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[9])) )
+    {
+        fputs("schedule_every_hour\n", fp);
+        script_hour = g_strdup_printf("%s", "*");
     }
+    /* Run every minute */
+    if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widgets->schedule_check_button[10])) )
+    {
+        fputs("schedule_every_minute\n", fp);
+        script_minute = g_strdup_printf("%s", "*");
+    }
+    
     /* Close the settings file */
     fclose(fp);
     g_free(settings_file);
 
-    /* If script_hour is zero or nothing, write it as any. '*' */
-    if( script_hour == NULL || script_hour[0]=='0' )
-      script_hour = g_strdup_printf("%s", "*");
-
-    /* If script_minute is zero or nothing, write it as any. '*' */
-    if( script_minute == NULL || script_minute[0]=='0' )
-      script_minute = g_strdup_printf("%s", "*");
-
     /* Schedule this backup in crontab */
-    cron_line = g_strdup_printf("%s %s * * %s root", script_minute, script_hour, script_days);
+    cron_line = g_strdup_printf("%s %s %s * %s root", script_minute, script_hour, script_month_day, script_days);
     free(script_days);
 
     /* Removes the old cron line, adds a new one and HUP's crond */
